import { PACKAGE_NAME } from './package-name.js';
import { getAllDeviceInfo } from './get-all-device-info.js';
/**
 * Inserts a device into the Deep
 *
 * @remarks
 * If the {@link InsertDeviceParam.info} parameter is undefined, the function will call {@link getAllDeviceInfo} to get the device information.
 * If the {@link InsertDeviceParam.containerLinkId} parameter is undefined, the device link will be contained in the {@link InsertDeviceParam.deep.linkId}.
 *
 * @example
 * ```ts
const {deviceLink} = await insertDevice({
  deep,
  containerLinkId: deep.linkId,
  info: await getAllDeviceInfo(),
});
 */
export async function insertDevice(param) {
    const { deep, info = await getAllDeviceInfo(), containerLinkId = deep.linkId, } = param;
    const deviceTypeLinkId = await deep.id(PACKAGE_NAME, 'Device');
    const containTypeLinkId = await deep.id('@deep-foundation/core', 'Contain');
    let { data: [deviceLink], } = await deep.insert({
        type_id: deviceTypeLinkId,
        in: {
            data: [
                {
                    type_id: containTypeLinkId,
                    from_id: containerLinkId,
                },
            ],
        },
        object: {
            data: {
                value: info,
            },
        },
    }, { returning: deep.selectReturning });
    return { deviceLink };
}
